@@ -2,13 +2,11 @@ package Alien::Build::Plugin::Build::Copy;
 
 use strict;
 use warnings;
-use 5.008004;
 use Alien::Build::Plugin;
 use Path::Tiny ();
 
 # ABSTRACT: Copy plugin for Alien::Build
-our $VERSION = '2.82_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+our $VERSION = '2.19'; # VERSION
 
 
 sub init
@@ -22,29 +20,14 @@ sub init
     $meta->register_hook(build => sub {
       my($build) = @_;
       my $stage = Path::Tiny->new($build->install_prop->{stage})->canonpath;
-      $build->system(qq{xcopy . "$stage" /E});
+      $build->system("xcopy . $stage /E");
     });
   }
-  elsif($^O eq 'darwin')
-  {
-    # On recent macOS -pPR is the same as -aR
-    # on older Mac OS X (10.5 at least) -a is not supported but -pPR is.
-
-    # Looks like -pPR should also work on coreutils if for some reason
-    # someone is using  coreutils on macOS, although there are semantic
-    # differences between -pPR and -aR on coreutils, that may or may not be
-    # important enough to care about.
-
-    $meta->register_hook(build => [
-      'cp -pPR * "%{.install.stage}"',
-    ]);
-  }
   else
   {
-    # TODO: some platforms might not support -a
-    # I think most platforms will support -r
     $meta->register_hook(build => [
-      'cp -aR * "%{.install.stage}"',
+      'cp -aR * %{.install.stage}',  # TODO: some platforms might not support -a
+                                     # I think most platforms will support -r
     ]);
   }
 }
@@ -63,7 +46,7 @@ Alien::Build::Plugin::Build::Copy - Copy plugin for Alien::Build
 
 =head1 VERSION
 
-version 2.82_01
+version 2.19
 
 =head1 SYNOPSIS
 
@@ -102,7 +85,7 @@ with the appropriate logic in your L<alienfile>.
    # alien dist on a platform that doesn't use it.
    requires 'Alien::Build::Plugin::Build::Copy';
  };
- 
+
  build {
    ...
    if($^O eq 'linux')
@@ -163,7 +146,7 @@ Juan Julián Merelo Guervós (JJ)
 
 Joel Berger (JBERGER)
 
-Petr Písař (ppisar)
+Petr Pisar (ppisar)
 
 Lance Wicks (LANCEW)
 
@@ -179,15 +162,9 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
-Håkon Hægland (hakonhagland, HAKONH)
-
-nick nauwelaerts (INPHOBIA)
-
-Florian Weimer
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2022 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
